# Table of Contents

- [relation-mapping-between-servicenow-and-sap-leanix](<./relation-mapping-between-servicenow-and-sap-leanix.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Relation Mapping Between ServiceNow and SAP LeanIX](<./Relation-Mapping-Between-ServiceNow-and-SAP-LeanIX.md>)
  - [Selecting an SAP LeanIX Relation](<./Relation-Mapping-Between-ServiceNow-and-SAP-LeanIX/Selecting-an-SAP-LeanIX-Relation.md>)
  - [Configuring a ServiceNow Relation](<./Relation-Mapping-Between-ServiceNow-and-SAP-LeanIX/Configuring-a-ServiceNow-Relation.md>)
  - [CMDB_REL_CI](<./Relation-Mapping-Between-ServiceNow-and-SAP-LeanIX/CMDB_REL_CI.md>)
  - [REFERENCE_FIELD](<./Relation-Mapping-Between-ServiceNow-and-SAP-LeanIX/REFERENCE_FIELD.md>)
  - [MAPPING_TABLE](<./Relation-Mapping-Between-ServiceNow-and-SAP-LeanIX/MAPPING_TABLE.md>)
  - [GRAPH_RULE_CONSTRAINT](<./Relation-Mapping-Between-ServiceNow-and-SAP-LeanIX/GRAPH_RULE_CONSTRAINT.md>)
  - [Relation Sync Behavior](<./Relation-Mapping-Between-ServiceNow-and-SAP-LeanIX/Relation-Sync-Behavior.md>)
